@@ -21,12 +21,10 @@ CONTEXT_SETTINGS = {'token_normalize_func': lambda x: x.upper()}
               required=True)
 @click.option('--iops',
               type=int,
-              help='Performance Storage IOPs,'
-              ' between 100 and 6000 in multiples of 100'
-              '  [required for storage-type performance]')
+              help="""Performance Storage IOPs. Options vary based on storage size.
+[required for storage-type performance]""")
 @click.option('--tier',
-              help='Endurance Storage Tier (IOP per GB)'
-              '  [required for storage-type endurance]',
+              help='Endurance Storage Tier (IOP per GB) [required for storage-type endurance]',
               type=click.Choice(['0.25', '2', '4', '10']))
 @click.option('--location',
               help='Datacenter short name (e.g.: dal09)',
@@ -37,34 +35,47 @@ CONTEXT_SETTINGS = {'token_normalize_func': lambda x: x.upper()}
               'space along with endurance file storage; specifies '
               'the size (in GB) of snapshot space to order')
 @click.option('--service-offering',
-              help='The service offering package to use for placing '
-              'the order [optional, default is \'storage_as_a_service\']',
+              help="""The service offering package to use for placing the order.
+[optional, default is \'storage_as_a_service\']. enterprise and performance are depreciated""",
               default='storage_as_a_service',
               type=click.Choice([
                   'storage_as_a_service',
                   'enterprise',
                   'performance']))
+@click.option('--billing',
+              type=click.Choice(['hourly', 'monthly']),
+              default='monthly',
+              help="Optional parameter for Billing rate (default to monthly)")
 @environment.pass_env
 def cli(env, storage_type, size, iops, tier,
-        location, snapshot_size, service_offering):
-    """Order a file storage volume."""
+        location, snapshot_size, service_offering, billing):
+    """Order a file storage volume.
+
+    Valid size and iops options can be found here:
+    https://cloud.ibm.com/docs/FileStorage/index.html#provisioning-considerations
+    """
     file_manager = SoftLayer.FileStorageManager(env.client)
     storage_type = storage_type.lower()
 
+    hourly_billing_flag = False
+    if billing.lower() == "hourly":
+        hourly_billing_flag = True
+
+    if service_offering != 'storage_as_a_service':
+        click.secho('{} is a legacy storage offering'.format(service_offering), fg='red')
+        if hourly_billing_flag:
+            raise exceptions.CLIAbort(
+                'Hourly billing is only available for the storage_as_a_service service offering'
+            )
+
     if storage_type == 'performance':
         if iops is None:
-            raise exceptions.CLIAbort(
-                'Option --iops required with Performance')
-
-        if iops % 100 != 0:
-            raise exceptions.CLIAbort(
-                'Option --iops must be a multiple of 100'
-            )
+            raise exceptions.CLIAbort('Option --iops required with Performance')
 
         if service_offering == 'performance' and snapshot_size is not None:
             raise exceptions.CLIAbort(
-                '--snapshot-size is not available for performance volumes '
-                'ordered with the \'performance\' service offering option'
+                '--snapshot-size is not available for performance service offerings. '
+                'Use --service-offering storage_as_a_service'
             )
 
         try:
@@ -74,7 +85,8 @@ def cli(env, storage_type, size, iops, tier,
                 size=size,
                 iops=iops,
                 snapshot_size=snapshot_size,
-                service_offering=service_offering
+                service_offering=service_offering,
+                hourly_billing_flag=hourly_billing_flag
             )
         except ValueError as ex:
             raise exceptions.ArgumentError(str(ex))
@@ -82,8 +94,7 @@ def cli(env, storage_type, size, iops, tier,
     if storage_type == 'endurance':
         if tier is None:
             raise exceptions.CLIAbort(
-                'Option --tier required with Endurance in IOPS/GB '
-                '[0.25,2,4,10]'
+                'Option --tier required with Endurance in IOPS/GB [0.25,2,4,10]'
             )
 
         try:
@@ -93,7 +104,8 @@ def cli(env, storage_type, size, iops, tier,
                 size=size,
                 tier_level=float(tier),
                 snapshot_size=snapshot_size,
-                service_offering=service_offering
+                service_offering=service_offering,
+                hourly_billing_flag=hourly_billing_flag
             )
         except ValueError as ex:
             raise exceptions.ArgumentError(str(ex))
@@ -104,5 +116,4 @@ def cli(env, storage_type, size, iops, tier,
         for item in order['placedOrder']['items']:
             click.echo(" > %s" % item['description'])
     else:
-        click.echo("Order could not be placed! Please verify your options " +
-                   "and try again.")
+        click.echo("Order could not be placed! Please verify your options and try again.")
