@@ -784,136 +784,201 @@ getAllObjects = [{
                  'sortOrder': 10}],
     'subDescription': 'Bare Metal Server',
     'unitSize': 1,
+    "itemPrices": [
+        {
+            "hourlyRecurringFee": ".027",
+            "id": 205911,
+            "laborFee": "0",
+            "locationGroupId": 505,
+            "item": {
+                "capacity": "0",
+                "description": "Load Balancer Uptime",
+                "id": 10785,
+                "keyName": "LOAD_BALANCER_UPTIME",
+            }
+        },
+        {
+            "hourlyRecurringFee": "0",
+            "id": 199467,
+            "laborFee": "0",
+            "locationGroupId": '',
+            "recurringFee": "0",
+            "item": {
+                "capacity": "0",
+                "description": "Load Balancer Bandwidth",
+                "id": 10051,
+                "keyName": "LOAD_BALANCER_BANDWIDTH",
+            }
+        },
+        {
+            "hourlyRecurringFee": ".028",
+            "id": 205913,
+            "laborFee": "0",
+            "locationGroupId": 507,
+            "item": {
+                "capacity": "0",
+                "description": "Load Balancer Uptime",
+                "id": 10785,
+                "keyName": "LOAD_BALANCER_UPTIME",
+            }
+        }]
 }]
 
 getItems = [
     {
         'id': 1234,
+        'keyName': 'KeyName01',
         'capacity': '1000',
         'description': 'Public & Private Networks',
         'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
         'prices': [{'id': 1122,
+                    'hourlyRecurringFee': 0.0,
+                    'recurringFee': 0.0,
                     'categories': [{'id': 26,
                                     'name': 'Uplink Port Speeds',
                                     'categoryCode': 'port_speed'}]}],
     },
     {
         'id': 2233,
+        'keyName': 'KeyName02',
         'capacity': '1000',
         'description': 'Public & Private Networks',
         'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
         'prices': [{'id': 4477,
+                    'hourlyRecurringFee': 0.0,
+                    'recurringFee': 0.0,
                     'categories': [{'id': 26,
                                     'name': 'Uplink Port Speeds',
                                     'categoryCode': 'port_speed'}]}],
     },
     {
         'id': 1239,
+        'keyName': 'KeyName03',
         'capacity': '2',
         'description': 'RAM',
         'itemCategory': {'categoryCode': 'RAM'},
         'prices': [{'id': 1133,
+                    'hourlyRecurringFee': 0.0,
+                    'recurringFee': 0.0,
                     'categories': [{'id': 3,
                                     'name': 'RAM',
                                     'categoryCode': 'ram'}]}],
     },
     {
         'id': 1240,
+        'keyName': 'KeyName014',
         'capacity': '4',
         'units': 'PRIVATE_CORE',
         'description': 'Computing Instance (Dedicated)',
         'itemCategory': {'categoryCode': 'Computing Instance'},
         'prices': [{'id': 1007,
+                    'hourlyRecurringFee': 0.0,
+                    'recurringFee': 0.0,
                     'categories': [{'id': 80,
                                     'name': 'Computing Instance',
                                     'categoryCode': 'guest_core'}]}],
     },
     {
         'id': 1250,
+        'keyName': 'KeyName015',
         'capacity': '4',
         'units': 'CORE',
         'description': 'Computing Instance',
         'itemCategory': {'categoryCode': 'Computing Instance'},
         'prices': [{'id': 1144,
                     'locationGroupId': None,
+                    'hourlyRecurringFee': 0.0,
+                    'recurringFee': 0.0,
                     'categories': [{'id': 80,
                                     'name': 'Computing Instance',
                                     'categoryCode': 'guest_core'}]}],
     },
     {
         'id': 112233,
+        'keyName': 'KeyName016',
         'capacity': '55',
         'units': 'CORE',
         'description': 'Computing Instance',
         'itemCategory': {'categoryCode': 'Computing Instance'},
         'prices': [{'id': 332211,
                     'locationGroupId': 1,
+                    'hourlyRecurringFee': 0.0,
+                    'recurringFee': 0.0,
                     'categories': [{'id': 80,
                                     'name': 'Computing Instance',
                                     'categoryCode': 'guest_core'}]}],
     },
     {
         'id': 4439,
+        'keyName': 'KeyName017',
         'capacity': '1',
         'description': '1 GB iSCSI Storage',
         'itemCategory': {'categoryCode': 'iscsi'},
-        'prices': [{'id': 2222}],
+        'prices': [{'id': 2222, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     },
     {
         'id': 1121,
+        'keyName': 'KeyName081',
         'capacity': '20',
         'description': '20 GB iSCSI snapshot',
         'itemCategory': {'categoryCode': 'iscsi_snapshot_space'},
-        'prices': [{'id': 2014}],
+        'prices': [{'id': 2014, 'hourlyRecurringFee': 0.0}],
     },
     {
         'id': 4440,
+        'keyName': 'KeyName019',
         'capacity': '4',
         'description': '4 Portable Public IP Addresses',
         'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
-        'prices': [{'id': 4444}],
+        'prices': [{'id': 4444, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     },
     {
         'id': 8880,
+        'keyName': 'KeyName0199',
         'capacity': '8',
         'description': '8 Portable Public IP Addresses',
         'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
-        'prices': [{'id': 8888}],
+        'prices': [{'id': 8888, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     },
     {
         'id': 44400,
+        'keyName': 'KeyName0155',
         'capacity': '4',
         'description': '4 Portable Private IP Addresses',
         'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
-        'prices': [{'id': 44441}],
+        'prices': [{'id': 44441, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     },
     {
         'id': 88800,
+        'keyName': 'KeyName0144',
         'capacity': '8',
         'description': '8 Portable Private IP Addresses',
         'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
-        'prices': [{'id': 88881}],
+        'prices': [{'id': 88881, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     },
     {
         'id': 10,
+        'keyName': 'KeyName0341',
         'capacity': '0',
         'description': 'Global IPv4',
         'itemCategory': {'categoryCode': 'global_ipv4'},
-        'prices': [{'id': 11}],
+        'prices': [{'id': 11, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     },
     {
         'id': 66464,
+        'keyName': 'KeyName0211',
         'capacity': '64',
         'description': '/64 Block Portable Public IPv6 Addresses',
         'itemCategory': {'categoryCode': 'static_ipv6_addresses'},
-        'prices': [{'id': 664641}],
+        'prices': [{'id': 664641, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     },
     {
         'id': 610,
+        'keyName': 'KeyName031',
         'capacity': '0',
         'description': 'Global IPv6',
         'itemCategory': {'categoryCode': 'global_ipv6'},
-        'prices': [{'id': 611}],
+        'prices': [{'id': 611, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
     }]
 
 getItemPricesISCSI = [
@@ -1123,6 +1188,91 @@ verifyOrderDH = {
     'quantity': 1
 }
 
+itemsLoadbal = [
+    {
+        "capacity": "0",
+        "description": "Load Balancer as a Service",
+        "id": 10043,
+        "keyName": "LOAD_BALANCER_AS_A_SERVICE",
+        "itemCategory": {
+            "categoryCode": "load_balancer_as_a_service",
+            "id": 1116,
+            "name": "Load Balancer As A Service",
+        },
+        "prices": [
+            {
+                "hourlyRecurringFee": "0",
+                "id": 199447,
+                "locationGroupId": '',
+                "recurringFee": "0",
+            }
+        ]
+    },
+    {
+        "capacity": "0",
+        "description": "Load Balancer Uptime",
+        "id": 10785,
+        "keyName": "LOAD_BALANCER_UPTIME",
+        "itemCategory": {
+            "categoryCode": "load_balancer_uptime",
+            "id": 1119,
+            "name": "Load Balancer Uptime",
+        },
+        "prices": [
+            {
+                "hourlyRecurringFee": ".028",
+                "id": 205913,
+                "locationGroupId": 507,
+            }]}
+]
+
+regionsLoadbal = [{'description': 'WDC01 - Washington, DC - East Coast U.S.',
+                   'keyname': 'WASHINGTON_DC',
+                   'location': {'location': {'id': 37473,
+                                             'longName': 'Washington 1',
+                                             'name': 'wdc01',
+                                             "groups": [
+                                                 {
+                                                     "description": "Location Group 4",
+                                                     "id": 507,
+                                                     "locationGroupTypeId": 82,
+                                                     "name": "Location Group 4",
+                                                     "locationGroupType": {
+                                                         "name": "PRICING"
+                                                     }
+                                                 },
+                                                 {
+                                                     "description": "COS Cross Region - EU",
+                                                     "id": 1303,
+                                                     "locationGroupTypeId": 82,
+                                                     "name": "eu",
+                                                     "locationGroupType": {
+                                                         "name": "PRICING"
+                                                     }
+                                                 },
+                                                 {
+                                                     "description": "COS Regional Frankfurt",
+                                                     "id": 1783,
+                                                     "locationGroupTypeId": 82,
+                                                     "name": "eu-de",
+                                                     "locationGroupType": {
+                                                         "name": "PRICING"
+                                                     }
+                                                 }
+                                             ]
+                                             }},
+                   'sortOrder': 10}]
+
+getAllObjectsLoadbal = [
+    {
+        "id": 805,
+        "keyName": "LBAAS",
+        "name": "Load Balancer As A Service (LBaaS)",
+        "items": itemsLoadbal,
+        "regions": regionsLoadbal
+    }
+]
+
 getAllObjectsDH = [{
     "subDescription": "Dedicated Host",
     "name": "Dedicated Host",
@@ -1346,6 +1496,11 @@ getItemPrices = [
         "hourlyRecurringFee": ".093",
         "id": 204015,
         "recurringFee": "62",
+        "categories": [
+            {
+                "categoryCode": "guest_core"
+            }
+        ],
         "item": {
             "description": "4 x 2.0 GHz or higher Cores",
             "id": 859,
@@ -1542,3 +1697,85 @@ getActivePresets = [
 ]
 
 getAccountRestrictedActivePresets = []
+
+RESERVED_CAPACITY = [{"id": 1059}]
+getItems_RESERVED_CAPACITY = [
+    {
+        'id': 12273,
+        'keyName': 'B1_1X2_1_YEAR_TERM',
+        'description': 'B1 1x2 1 year term',
+        'capacity': 12,
+        'itemCategory': {
+            'categoryCode': 'reserved_capacity',
+            'id': 2060,
+            'name': 'Reserved Capacity',
+            'quantityLimit': 20,
+            'sortOrder': ''
+        },
+        'prices': [
+            {
+                'currentPriceFlag': '',
+                'hourlyRecurringFee': '.032',
+                'id': 217561,
+                'itemId': 12273,
+                'laborFee': '0',
+                'locationGroupId': '',
+                'onSaleFlag': '',
+                'oneTimeFee': '0',
+                'quantity': '',
+                'setupFee': '0',
+                'sort': 0,
+                'tierMinimumThreshold': '',
+                'categories': [
+                    {
+                        'categoryCode': 'reserved_capacity',
+                        'id': 2060,
+                        'name': 'Reserved Capacity',
+                        'quantityLimit': 20,
+                        'sortOrder': ''
+                    }
+                ]
+            }
+        ]
+    }
+]
+
+getItems_1_IPV6_ADDRESS = [
+    {
+        'id': 4097,
+        'keyName': '1_IPV6_ADDRESS',
+        'itemCategory': {
+            'categoryCode': 'pri_ipv6_addresses',
+            'id': 325,
+            'name': 'Primary IPv6 Addresses',
+            'quantityLimit': 0,
+            'sortOrder': 34
+        },
+        'prices': [
+            {
+                'currentPriceFlag': '',
+                'hourlyRecurringFee': '0',
+                'id': 17129,
+                'itemId': 4097,
+                'laborFee': '0',
+                'locationGroupId': '',
+                'onSaleFlag': '',
+                'oneTimeFee': '0',
+                'quantity': '',
+                'recurringFee': '0',
+                'setupFee': '0',
+                'sort': 0,
+                'tierMinimumThreshold': '',
+                'categories': [
+                    {
+                        'categoryCode': 'pri_ipv6_addresses',
+                        'id': 325,
+                        'name': 'Primary IPv6 Addresses',
+                        'quantityLimit': 0,
+                        'sortOrder': 34
+                    }
+                ]
+            }
+        ]
+    }
+]
