@@ -24,6 +24,7 @@ from SoftLayer.managers.object_storage import ObjectStorageManager
 from SoftLayer.managers.ordering import OrderingManager
 from SoftLayer.managers.sshkey import SshKeyManager
 from SoftLayer.managers.ssl import SSLManager
+from SoftLayer.managers.tags import TagManager
 from SoftLayer.managers.ticket import TicketManager
 from SoftLayer.managers.user import UserManager
 from SoftLayer.managers.vs import VSManager
@@ -50,6 +51,7 @@ __all__ = [
     'PlacementManager',
     'SshKeyManager',
     'SSLManager',
+    'TagManager',
     'TicketManager',
     'UserManager',
     'VSManager',
