@@ -50,6 +50,7 @@ class FileTests(testing.TestCase):
                 'username': 'user',
                 'active_transactions': None,
                 'mount_addr': '127.0.0.1:/TEST',
+                'notes': None,
                 'rep_partner_count': None
             }],
             json.loads(result.output))
@@ -137,6 +138,7 @@ class FileTests(testing.TestCase):
             'Data Center': 'dal05',
             'Type': 'ENDURANCE',
             'ID': 100,
+            'Notes': "{'status': 'available'}",
             '# of Active Transactions': '1',
             'Ongoing Transaction': 'This is a buffer time in which the customer may cancel the server',
             'Replicant Count': '1',
@@ -163,6 +165,24 @@ class FileTests(testing.TestCase):
             ]
         }, json.loads(result.output))
 
+    def test_volume_detail_name_identifier(self):
+        result = self.run_command(['file', 'volume-detail', 'SL-12345'])
+        expected_filter = {
+            'nasNetworkStorage': {
+                'serviceResource': {
+                    'type': {
+                        'type': {'operation': '!~ NAS'}
+                    }
+                },
+                'storageType': {
+                    'keyName': {'operation': '*= FILE_STORAGE'}
+                },
+                'username': {'operation': '_= SL-12345'}}}
+
+        self.assert_called_with('SoftLayer_Account', 'getNasNetworkStorage', filter=expected_filter)
+        self.assert_called_with('SoftLayer_Network_Storage', 'getObject', identifier=1)
+        self.assert_no_fail(result)
+
     def test_volume_order_performance_iops_not_given(self):
         result = self.run_command(['file', 'volume-order',
                                    '--storage-type=performance', '--size=20',
@@ -444,7 +464,7 @@ class FileTests(testing.TestCase):
 
     def test_replicant_failover(self):
         result = self.run_command(['file', 'replica-failover', '12345678',
-                                   '--replicant-id=5678', '--immediate'])
+                                   '--replicant-id=5678'])
 
         self.assert_no_fail(result)
         self.assertEqual('Failover to replicant is now in progress.\n',
@@ -461,8 +481,7 @@ class FileTests(testing.TestCase):
                          result.output)
 
     def test_replicant_failback(self):
-        result = self.run_command(['file', 'replica-failback', '12345678',
-                                   '--replicant-id=5678'])
+        result = self.run_command(['file', 'replica-failback', '12345678'])
 
         self.assert_no_fail(result)
         self.assertEqual('Failback from replicant is now in progress.\n',
@@ -472,8 +491,7 @@ class FileTests(testing.TestCase):
     def test_replicant_failback_unsuccessful(self, failback_mock):
         failback_mock.return_value = False
 
-        result = self.run_command(['file', 'replica-failback', '12345678',
-                                   '--replicant-id=5678'])
+        result = self.run_command(['file', 'replica-failback', '12345678'])
 
         self.assertEqual('Failback operation could not be initiated.\n',
                          result.output)
@@ -631,7 +649,8 @@ class FileTests(testing.TestCase):
                                       duplicate_size=250, duplicate_iops=None,
                                       duplicate_tier_level=2,
                                       duplicate_snapshot_size=20,
-                                      hourly_billing_flag=True)
+                                      hourly_billing_flag=True,
+                                      dependent_duplicate=False)
         self.assert_no_fail(result)
         self.assertEqual(result.output,
                          'Order #24602 placed successfully!\n'
@@ -667,3 +686,42 @@ class FileTests(testing.TestCase):
         self.assert_no_fail(result)
         self.assertEqual('Order #24602 placed successfully!\n > Storage as a Service\n > 1000 GBs\n > 4 IOPS per GB\n',
                          result.output)
+
+    @mock.patch('SoftLayer.FileStorageManager.list_file_volume_limit')
+    def test_volume_limit(self, list_mock):
+        list_mock.return_value = [
+            {
+                'datacenterName': 'global',
+                'maximumAvailableCount': 300,
+                'provisionedCount': 100
+            }]
+        result = self.run_command(['file', 'volume-limits'])
+        self.assert_no_fail(result)
+
+    def test_dupe_refresh(self):
+        result = self.run_command(['file', 'volume-refresh', '102', '103'])
+
+        self.assert_no_fail(result)
+
+    def test_dep_dupe_convert(self):
+        result = self.run_command(['file', 'volume-convert', '102'])
+
+        self.assert_no_fail(result)
+
+    @mock.patch('SoftLayer.FileStorageManager.volume_set_note')
+    def test_volume_set_note(self, set_note):
+        set_note.return_value = True
+
+        result = self.run_command(['file', 'volume-set-note', '102', '--note=testing'])
+
+        self.assert_no_fail(result)
+        self.assertIn("successfully!", result.output)
+
+    @mock.patch('SoftLayer.FileStorageManager.volume_set_note')
+    def test_volume_not_set_note(self, set_note):
+        set_note.return_value = False
+
+        result = self.run_command(['file', 'volume-set-note', '102', '--note=testing'])
+
+        self.assert_no_fail(result)
+        self.assertIn("Note could not be set!", result.output)
