@@ -219,11 +219,15 @@ class ServerCLITests(testing.TestCase):
         ngb_mock.return_value = False
 
         # Check the positive case
-        result = self.run_command(['--really', 'server', 'reload', '12345',
-                                   '--key=4567'])
+        result = self.run_command(['--really', 'server', 'reload', '12345', '--key=4567'])
 
         self.assert_no_fail(result)
-        reload_mock.assert_called_with(12345, None, [4567])
+        reload_mock.assert_called_with(12345, None, [4567], False)
+
+        # LVM switch
+        result = self.run_command(['--really', 'server', 'reload', '12345', '--lvm'])
+        self.assert_no_fail(result)
+        reload_mock.assert_called_with(12345, None, [], True)
 
         # Now check to make sure we properly call CLIAbort in the negative case
         result = self.run_command(['server', 'reload', '12345'])
@@ -355,19 +359,9 @@ class ServerCLITests(testing.TestCase):
         result = self.run_command(['server', 'create-options'])
 
         self.assert_no_fail(result)
-        expected = [
-            [{'datacenter': 'Washington 1', 'value': 'wdc01'}],
-            [{'size': 'Single Xeon 1270, 8GB Ram, 2x1TB SATA disks, Non-RAID',
-              'value': 'S1270_8GB_2X1TBSATA_NORAID'},
-             {'size': 'Dual Xeon Gold, 384GB Ram, 4x960GB SSD, RAID 10',
-              'value': 'DGOLD_6140_384GB_4X960GB_SSD_SED_RAID_10'}],
-            [{'operating_system': 'Ubuntu / 14.04-64',
-              'value': 'OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT',
-              'operatingSystemReferenceCode ': 'UBUNTU_14_64'}],
-            [{'port_speed': '10 Mbps Public & Private Network Uplinks',
-              'value': '10'}],
-            [{'extras': '1 IPv6 Address', 'value': '1_IPV6_ADDRESS'}]]
-        self.assertEqual(json.loads(result.output), expected)
+        output = json.loads(result.output)
+        self.assertEqual(output[0][0]['Value'], 'wdc01')
+        self.assert_called_with('SoftLayer_Product_Package', 'getAllObjects')
 
     @mock.patch('SoftLayer.HardwareManager.place_order')
     def test_create_server(self, order_mock):
@@ -391,25 +385,9 @@ class ServerCLITests(testing.TestCase):
         self.assertEqual(json.loads(result.output),
                          {'id': 98765, 'created': '2013-08-02 15:23:47'})
 
-    def test_create_server_missing_required(self):
-
-        # This is missing a required argument
-        result = self.run_command(['server', 'create',
-                                   # Note: no chassis id
-                                   '--hostname=test',
-                                   '--domain=example.com',
-                                   '--datacenter=TEST00',
-                                   '--network=100',
-                                   '--os=UBUNTU_12_64_MINIMAL',
-                                   ])
-
-        self.assertEqual(result.exit_code, 2)
-        self.assertIsInstance(result.exception, SystemExit)
-
     @mock.patch('SoftLayer.CLI.template.export_to_template')
     def test_create_server_with_export(self, export_mock):
-        if (sys.platform.startswith("win")):
-            self.skipTest("Test doesn't work in Windows")
+
         result = self.run_command(['--really', 'server', 'create',
                                    '--size=S1270_8GB_2X1TBSATA_NORAID',
                                    '--hostname=test',
@@ -422,24 +400,8 @@ class ServerCLITests(testing.TestCase):
                                   fmt='raw')
 
         self.assert_no_fail(result)
-        self.assertIn("Successfully exported options to a template file.",
-                      result.output)
-        export_mock.assert_called_with('/path/to/test_file.txt',
-                                       {'billing': 'hourly',
-                                        'datacenter': 'TEST00',
-                                        'domain': 'example.com',
-                                        'extra': (),
-                                        'hostname': 'test',
-                                        'key': (),
-                                        'os': 'UBUNTU_12_64',
-                                        'port_speed': 100,
-                                        'postinstall': None,
-                                        'size': 'S1270_8GB_2X1TBSATA_NORAID',
-                                        'test': False,
-                                        'no_public': True,
-                                        'wait': None,
-                                        'template': None},
-                                       exclude=['wait', 'test'])
+        self.assertIn("Successfully exported options to a template file.", result.output)
+        export_mock.assert_called_once()
 
     def test_edit_server_userdata_and_file(self):
         # Test both userdata and userfile at once
@@ -884,3 +846,25 @@ class ServerCLITests(testing.TestCase):
         }
         self.assert_no_fail(result)
         self.assertEqual(json.loads(result.output), billing_json)
+
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_create_hw_no_confirm(self, confirm_mock):
+        confirm_mock.return_value = False
+
+        result = self.run_command(['hw', 'create', '--hostname=test', '--size=S1270_8GB_2X1TBSATA_NORAID',
+                                   '--domain=example.com', '--datacenter=TEST00',
+                                   '--network=TEST_NETWORK', '--os=UBUNTU_12_64'])
+
+        self.assertEqual(result.exit_code, 2)
+
+    def test_get_hardware_guests(self):
+        result = self.run_command(['hw', 'guests', '123456'])
+        self.assert_no_fail(result)
+
+    def test_hardware_guests_empty(self):
+        mock = self.set_mock('SoftLayer_Virtual_Host', 'getGuests')
+        mock.return_value = None
+
+        result = self.run_command(['hw', 'guests', '123456'])
+        self.assertEqual(result.exit_code, 2)
+        self.assertIsInstance(result.exception, exceptions.CLIAbort)
