@@ -1132,3 +1132,45 @@ class VSTests(testing.TestCase):
                 }
             }
         ], result)
+
+    def test_migrate(self):
+        result = self.vs.migrate(1234)
+        self.assertTrue(result)
+        self.assert_called_with('SoftLayer_Virtual_Guest', 'migrate', identifier=1234)
+
+    def test_migrate_dedicated(self):
+        result = self.vs.migrate_dedicated(1234, 5555)
+        self.assertTrue(result)
+        self.assert_called_with('SoftLayer_Virtual_Guest', 'migrateDedicatedHost', args=(5555,), identifier=1234)
+
+    def test_get_hardware_guests(self):
+        mock = self.set_mock('SoftLayer_Account', 'getHardware')
+        mock.return_value = [{
+            "accountId": 11111,
+            "domain": "vmware.chechu.com",
+            "hostname": "host14",
+            "id": 22222,
+            "virtualHost": {
+                "accountId": 11111,
+                "id": 33333,
+                "name": "host14.vmware.chechu.com",
+                "guests": [
+                    {
+                        "accountId": 11111,
+                        "hostname": "NSX-T Manager",
+                        "id": 44444,
+                        "maxCpu": 16,
+                        "maxCpuUnits": "CORE",
+                        "maxMemory": 49152,
+                        "powerState": {
+                            "keyName": "RUNNING",
+                            "name": "Running"
+                        },
+                        "status": {
+                            "keyName": "ACTIVE",
+                            "name": "Active"
+                        }
+                    }]}}]
+
+        result = self.vs.get_hardware_guests()
+        self.assertEqual("NSX-T Manager", result[0]['virtualHost']['guests'][0]['hostname'])
